@@ -55,18 +55,10 @@ QVariant RunnerMatchesModel::data(const QModelIndex &index, int role) const
             return match.data().toString();
         }
     } else if (role == Kicker::UrlRole) {
-        const QString &runnerId = match.runner()->id();
-        if (runnerId == QLatin1String("baloosearch") || runnerId == QLatin1String("bookmarks") || runnerId == QLatin1String("recentdocuments")) {
-            return QUrl(match.data().toString());
-        } else if (runnerId == QLatin1String("services")) {
-            const QString result = match.data().toString();
-            if (result.startsWith(QLatin1String("applications:"))) {
-                KService::Ptr service = KService::serviceByStorageId(result.mid(13));
+        const QList<QUrl> urls = match.urls();
 
-                if (service) {
-                    return QUrl::fromLocalFile(Kicker::resolvedServiceEntryPath(service));
-                }
-            }
+        if (!urls.isEmpty()) {
+            return urls.first();
         }
     } else if (role == Kicker::HasActionListRole) {
         return match.runner()->id() == QLatin1String("services") || !match.runner()->findChildren<QAction *>().isEmpty();
