@@ -72,6 +72,7 @@ KCMColors::KCMColors(QObject *parent, const KPluginMetaData &data, const QVarian
     });
 
     connect(colorsSettings(), &ColorsSettings::accentColorChanged, this, &KCMColors::accentColorChanged);
+    connect(colorsSettings(), &ColorsSettings::accentColorFromWallpaperChanged, this, &KCMColors::accentColorFromWallpaperChanged);
 
     connect(m_model, &ColorsModel::selectedSchemeChanged, m_filteredModel, &FilterProxyModel::setSelectedScheme);
     m_filteredModel->setSourceModel(m_model);
@@ -114,10 +115,9 @@ QColor KCMColors::accentColor() const
     return color;
 }
 
-QColor KCMColors::tinted(const QColor& color, const QColor& accent, bool tints, qreal tintFactor)
+QColor KCMColors::tinted(const QColor &color, const QColor &accent, bool tints, qreal tintFactor)
 {
-    if (accent == QColor(Qt::transparent) || !tints)
-    {
+    if (accent == QColor(Qt::transparent) || !tints) {
         return color;
     }
     return tintColor(color, accentColor(), tintFactor);
@@ -129,16 +129,37 @@ void KCMColors::setAccentColor(const QColor &accentColor)
     Q_EMIT settingsChanged();
 }
 
-bool KCMColors::applyAccentColorFromWallpaper() const
+bool KCMColors::accentColorFromWallpaper() const
 {
     return colorsSettings()->accentColorFromWallpaper();
 }
-void KCMColors::setApplyAccentColorFromWallpaper(bool boolean)
+
+void KCMColors::setAccentColorFromWallpaper(bool boolean)
 {
+    if (boolean == colorsSettings()->accentColorFromWallpaper()) {
+        return;
+    }
+    if (boolean) {
+        applyWallpaperAccentColor();
+    }
     colorsSettings()->setAccentColorFromWallpaper(boolean);
+    Q_EMIT accentColorFromWallpaperChanged();
     Q_EMIT settingsChanged();
 }
 
+QColor KCMColors::lastUsedCustomAccentColor() const
+{
+    return colorsSettings()->lastUsedCustomAccentColor();
+}
+void KCMColors::setLastUsedCustomAccentColor(const QColor &accentColor)
+{
+    if (accentColor == QColor(Qt::transparent)) {
+        return;
+    }
+    colorsSettings()->setLastUsedCustomAccentColor(accentColor);
+    Q_EMIT lastUsedCustomAccentColorChanged();
+    Q_EMIT settingsChanged();
+}
 bool KCMColors::downloadingFile() const
 {
     return m_tempCopyJob;
@@ -354,7 +375,7 @@ void KCMColors::load()
 
     loadSelectedColorScheme();
 
-    Q_EMIT applyAccentColorFromWallpaperChanged();
+    Q_EMIT accentColorFromWallpaperChanged();
     Q_EMIT accentColorChanged();
 
     // If need save is true at the end of load() function, it will stay disabled forever.
@@ -386,31 +407,20 @@ void KCMColors::save()
     m_activeSchemeEdited = false;
 
     processPendingDeletions();
+
+    QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/kdeglobals"), QStringLiteral("org.kde.kconfig.notify"), QStringLiteral("ConfigChanged"));
+    const QHash<QString, QByteArrayList> changes = {{QStringLiteral("General"), {"accentColorFromWallpaper", "AccentColor"}}};
+    message.setArguments({QVariant::fromValue(changes)});
+    QDBusConnection::sessionBus().send(message);
 }
 
 void KCMColors::saveColors()
 {
     const QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("color-schemes/%1.colors").arg(m_model->selectedScheme()));
-    // hard to figure out why mutating from the colours settings
-    // doesn't affect the applicator's view on config, but operating on the
-    // globalConfig directly works.
-    // code already a mess, so might as well just do what works.
-    KSharedConfigPtr globalConfig = KSharedConfig::openConfig(QStringLiteral("kdeglobals"));
 
-    auto setGlobals = [=]() {
-        globalConfig->group("General").writeEntry("AccentColor", QColor());
-        globalConfig->group("General").writeEntry("accentColorFromWallpaper", applyAccentColorFromWallpaper(), KConfig::Notify);
-        if (accentColor() != QColor(Qt::transparent)) {
-            globalConfig->group("General").writeEntry("AccentColor", accentColor(), KConfig::Notify);
-        } else {
-            globalConfig->group("General").deleteEntry("AccentColor", KConfig::Notify);
-        }
-    };
-
-    setGlobals();
-    applyScheme(path, colorsSettings()->config());
+    // Can't use KConfig readEntry because the config is not saved yet
+    applyScheme(path, colorsSettings()->config(), KConfig::Normal, accentColor());
     m_selectedSchemeDirty = false;
-    setGlobals();
 }
 
 QColor KCMColors::accentBackground(const QColor &accent, const QColor &background)
@@ -430,7 +440,7 @@ void KCMColors::applyWallpaperAccentColor()
     QDBusPendingCall async = connection.asyncCall(accentColor);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(async, this);
 
-    QObject::connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher *)), this, SLOT(wallpaperAccentColorArrivedSlot(QDBusPendingCallWatcher *)));
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, &KCMColors::wallpaperAccentColorArrivedSlot);
 }
 
 void KCMColors::wallpaperAccentColorArrivedSlot(QDBusPendingCallWatcher *call)
