@@ -34,7 +34,11 @@
 #include <QUrlQuery>
 #include <QVBoxLayout>
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 #include <X11/Xlib.h>
 
 #include <fontconfig/fontconfig.h>
