@@ -27,6 +27,7 @@
 #include <pwd.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <kio_version.h>
 
 static constexpr int s_MAX_IPC_SIZE = 1024 * 32;
 
@@ -204,9 +205,9 @@ void CKioFonts::put(const QUrl &url, int /*permissions*/, KIO::JobFlags /*flags*
     EFolder folder(getFolder(pathList));
 
     if (!Misc::root() && FOLDER_ROOT == folder) {
-        error(KIO::ERR_SLAVE_DEFINED, i18n("Can only install fonts to either \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
+        error(KIO::ERR_WORKER_DEFINED, i18n("Can only install fonts to either \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
     } else if (Misc::isPackage(url.fileName())) {
-        error(KIO::ERR_SLAVE_DEFINED,
+        error(KIO::ERR_WORKER_DEFINED,
               i18n("You cannot install a fonts package directly.\n"
                    "Please extract %1, and install the components individually.",
                    url.toDisplayString()));
@@ -435,12 +436,12 @@ void CKioFonts::get(const QUrl &url)
 
 void CKioFonts::copy(const QUrl &, const QUrl &, int, KIO::JobFlags)
 {
-    error(KIO::ERR_SLAVE_DEFINED, i18n("Cannot copy fonts"));
+    error(KIO::ERR_WORKER_DEFINED, i18n("Cannot copy fonts"));
 }
 
 void CKioFonts::rename(const QUrl &, const QUrl &, KIO::JobFlags)
 {
-    error(KIO::ERR_SLAVE_DEFINED, i18n("Cannot move fonts"));
+    error(KIO::ERR_WORKER_DEFINED, i18n("Cannot move fonts"));
 }
 
 void CKioFonts::del(const QUrl &url, bool isFile)
@@ -451,9 +452,9 @@ void CKioFonts::del(const QUrl &url, bool isFile)
     QString name(removeKnownExtension(url));
 
     if (!isFile) {
-        error(KIO::ERR_SLAVE_DEFINED, i18n("Only fonts may be deleted."));
+        error(KIO::ERR_WORKER_DEFINED, i18n("Only fonts may be deleted."));
     } else if (!Misc::root() && FOLDER_ROOT == folder) {
-        error(KIO::ERR_SLAVE_DEFINED, i18n("Can only remove fonts from either \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
+        error(KIO::ERR_WORKER_DEFINED, i18n("Can only remove fonts from either \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
     } else if (!name.isEmpty()) {
         handleResp(m_interface->uninstall(name, Misc::root() || FOLDER_SYS == folder), name);
     } else {
@@ -480,7 +481,7 @@ void CKioFonts::stat(const QUrl &url)
         } else if (FOLDER_SYS == folder || FOLDER_USER == folder) {
             createUDSEntry(entry, folder);
         } else {
-            error(KIO::ERR_SLAVE_DEFINED, i18n("Please specify \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
+            error(KIO::ERR_WORKER_DEFINED, i18n("Please specify \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
             return;
         }
         break;
@@ -703,26 +704,26 @@ void CKioFonts::handleResp(int resp, const QString &file, const QString &tempFil
 {
     switch (resp) {
     case FontInst::STATUS_NO_SYS_CONNECTION:
-        error(KIO::ERR_SLAVE_DEFINED, i18n("Failed to start the system daemon"));
+        error(KIO::ERR_WORKER_DEFINED, i18n("Failed to start the system daemon"));
         break;
     case FontInst::STATUS_SERVICE_DIED:
-        error(KIO::ERR_SLAVE_DEFINED, i18n("Backend died"));
+        error(KIO::ERR_WORKER_DEFINED, i18n("Backend died"));
         break;
     case FontInst::STATUS_BITMAPS_DISABLED:
-        error(KIO::ERR_SLAVE_DEFINED, i18n("%1 is a bitmap font, and these have been disabled on your system.", file));
+        error(KIO::ERR_WORKER_DEFINED, i18n("%1 is a bitmap font, and these have been disabled on your system.", file));
         break;
     case FontInst::STATUS_ALREADY_INSTALLED:
-        error(KIO::ERR_SLAVE_DEFINED, i18n("%1 contains the font <b>%2</b>, which is already installed on your system.", file, FC::getName(tempFile)));
+        error(KIO::ERR_WORKER_DEFINED, i18n("%1 contains the font <b>%2</b>, which is already installed on your system.", file, FC::getName(tempFile)));
         break;
     case FontInst::STATUS_NOT_FONT_FILE:
-        error(KIO::ERR_SLAVE_DEFINED, i18n("%1 is not a font.", file));
+        error(KIO::ERR_WORKER_DEFINED, i18n("%1 is not a font.", file));
         break;
     case FontInst::STATUS_PARTIAL_DELETE:
-        error(KIO::ERR_SLAVE_DEFINED, i18n("Could not remove all files associated with %1", file));
+        error(KIO::ERR_WORKER_DEFINED, i18n("Could not remove all files associated with %1", file));
         break;
     case KIO::ERR_FILE_ALREADY_EXIST: {
         QString name(Misc::modifyName(file)), destFolder(Misc::getDestFolder(m_interface->folderName(destIsSystem), name));
-        error(KIO::ERR_SLAVE_DEFINED, i18n("<i>%1</i> already exists.", destFolder + name));
+        error(KIO::ERR_WORKER_DEFINED, i18n("<i>%1</i> already exists.", destFolder + name));
         break;
     }
     case FontInst::STATUS_OK:
