@@ -31,6 +31,14 @@ class HistoryItem;
 class KNotification;
 class KSystemClipboard;
 
+namespace KWayland
+{
+namespace Client
+{
+class PlasmaShell;
+}
+}
+
 enum class KlipperMode {
     Standalone,
     DataEngine,
@@ -65,6 +73,8 @@ public:
     Klipper(QObject *parent, const KSharedConfigPtr &config, KlipperMode mode = KlipperMode::Standalone);
     ~Klipper() override;
 
+    bool eventFilter(QObject *object, QEvent *event) override;
+
     /**
      * Get clipboard history (the "document")
      */
@@ -148,10 +158,11 @@ Q_SIGNALS:
 public Q_SLOTS:
     void slotPopupMenu();
     void slotAskClearHistory();
+    void setURLGrabberEnabled(bool);
+
 protected Q_SLOTS:
     void showPopupMenu(QMenu *);
     void slotRepeatAction();
-    void setURLGrabberEnabled(bool);
     void disableURLGrabber();
 
 private Q_SLOTS:
@@ -222,4 +233,5 @@ private:
     KlipperMode m_mode;
     QTimer *m_saveFileTimer = nullptr;
     QPointer<KNotification> m_notification;
+    KWayland::Client::PlasmaShell *m_plasmashell;
 };
