@@ -10,6 +10,7 @@
 
 #include <QAbstractItemModel>
 #include <QAbstractProxyModel>
+#include <QConcatenateTablesProxyModel>
 #include <QCoreApplication>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
@@ -19,8 +20,6 @@
 #include <QSettings>
 #include <QTextStream>
 
-#include <KConcatenateRowsProxyModel>
-
 #include <KProcessList>
 
 using namespace NotificationManager;
@@ -109,8 +108,8 @@ QModelIndex Utils::mapToModel(const QModelIndex &idx, const QAbstractItemModel *
     while (resolvedIdx.isValid() && resolvedIdx.model() != sourceModel) {
         if (auto *proxyModel = qobject_cast<const QAbstractProxyModel *>(resolvedIdx.model())) {
             resolvedIdx = proxyModel->mapToSource(resolvedIdx);
-            // KConcatenateRowsProxyModel isn't a "real" proxy model, so we need to special case for it :(
-        } else if (auto *concatenateModel = qobject_cast<const KConcatenateRowsProxyModel *>(resolvedIdx.model())) {
+            // QConcatenateTablesProxyModel isn't a "real" proxy model, so we need to special case for it :(
+        } else if (auto *concatenateModel = qobject_cast<const QConcatenateTablesProxyModel *>(resolvedIdx.model())) {
             resolvedIdx = concatenateModel->mapToSource(resolvedIdx);
         } else {
             if (resolvedIdx.model() != sourceModel) {
