@@ -6,13 +6,13 @@
 
 #include "screencasting.h"
 #include "qwayland-zkde-screencast-unstable-v1.h"
-#include <KWayland/Client/output.h>
-#include <KWayland/Client/plasmawindowmanagement.h>
-#include <KWayland/Client/registry.h>
 #include <QDebug>
-#include <QRect>
-
-using namespace KWayland::Client;
+#include <QGuiApplication>
+#include <QPointer>
+#include <QScreen>
+#include <QWaylandClientExtensionTemplate>
+#include <qpa/qplatformnativeinterface.h>
+#include <qtwaylandclientversion.h>
 
 class ScreencastingStreamPrivate : public QtWayland::zkde_screencast_stream_unstable_v1
 {
@@ -60,19 +60,24 @@ quint32 ScreencastingStream::nodeId() const
     return d->m_nodeId;
 }
 
-class ScreencastingPrivate : public QtWayland::zkde_screencast_unstable_v1
+class ScreencastingPrivate : public QWaylandClientExtensionTemplate<ScreencastingPrivate>, public QtWayland::zkde_screencast_unstable_v1
 {
 public:
-    ScreencastingPrivate(Registry *registry, int id, int version, Screencasting *q)
-        : QtWayland::zkde_screencast_unstable_v1(*registry, id, version)
+    ScreencastingPrivate(Screencasting *q)
+        : QWaylandClientExtensionTemplate<ScreencastingPrivate>(ZKDE_SCREENCAST_UNSTABLE_V1_STREAM_REGION_SINCE_VERSION)
         , q(q)
     {
-    }
+#if QTWAYLANDCLIENT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
+        initialize();
+#else
+        // QWaylandClientExtensionTemplate invokes this with a QueuedConnection but we want it called immediately
+        QMetaObject::invokeMethod(this, "addRegistryListener", Qt::DirectConnection);
+#endif
 
-    ScreencastingPrivate(::zkde_screencast_unstable_v1 *screencasting, Screencasting *q)
-        : QtWayland::zkde_screencast_unstable_v1(screencasting)
-        , q(q)
-    {
+        if (!isInitialized()) {
+            qWarning() << "Remember requesting the interface on your desktop file: X-KDE-Wayland-Interfaces=zkde_screencast_unstable_v1";
+        }
+        Q_ASSERT(isInitialized());
     }
 
     ~ScreencastingPrivate()
@@ -85,29 +90,28 @@ public:
 
 Screencasting::Screencasting(QObject *parent)
     : QObject(parent)
-{
-}
-
-Screencasting::Screencasting(Registry *registry, int id, int version, QObject *parent)
-    : QObject(parent)
-    , d(new ScreencastingPrivate(registry, id, version, this))
+    , d(new ScreencastingPrivate(this))
 {
 }
 
 Screencasting::~Screencasting() = default;
 
-ScreencastingStream *Screencasting::createOutputStream(Output *output, CursorMode mode)
+ScreencastingStream *Screencasting::createOutputStream(const QString &outputName, Screencasting::CursorMode mode)
 {
-    auto stream = new ScreencastingStream(this);
-    stream->setObjectName(output->model());
-    stream->d->init(d->stream_output(*output, mode));
-    return stream;
-}
+    wl_output *output = nullptr;
+    for (auto screen : qGuiApp->screens()) {
+        if (screen->name() == outputName) {
+            output = (wl_output *)QGuiApplication::platformNativeInterface()->nativeResourceForScreen("output", screen);
+        }
+    }
 
-ScreencastingStream *Screencasting::createWindowStream(PlasmaWindow *window, CursorMode mode)
-{
-    auto stream = createWindowStream(QString::fromUtf8(window->uuid()), mode);
-    stream->setObjectName(window->appId());
+    if (!output) {
+        return nullptr;
+    }
+
+    auto stream = new ScreencastingStream(this);
+    stream->setObjectName(outputName);
+    stream->d->init(d->stream_output(output, mode));
     return stream;
 }
 
@@ -118,11 +122,6 @@ ScreencastingStream *Screencasting::createWindowStream(const QString &uuid, Curs
     return stream;
 }
 
-void Screencasting::setup(::zkde_screencast_unstable_v1 *screencasting)
-{
-    d.reset(new ScreencastingPrivate(screencasting, this));
-}
-
 void Screencasting::destroy()
 {
     d.reset(nullptr);
