@@ -157,6 +157,14 @@ private:
         QUrl url(service->storageId());
         url.setScheme(QStringLiteral("applications"));
         match.setData(url);
+
+        QString path = service->entryPath();
+        if (!QDir::isAbsolutePath(path)) {
+            path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kservices5/") + path);
+        }
+
+        match.setUrls({QUrl::fromLocalFile(path)});
+
         QString exec = service->exec();
         // We have a snap, remove the ENV variable
         if (exec.contains(QLatin1String("BAMF_DESKTOP_FILE_HINT"))) {
@@ -256,11 +264,11 @@ private:
                 } else {
                     continue;
                 }
-            } else if (service->name().contains(queryList[0], Qt::CaseInsensitive)) {
+            } else if (name.contains(queryList[0], Qt::CaseInsensitive)) {
                 relevance = 0.8;
                 relevance += increaseMatchRelavance(service, queryList, QStringLiteral("Name"));
 
-                if (service->name().startsWith(queryList[0], Qt::CaseInsensitive)) {
+                if (name.startsWith(queryList[0], Qt::CaseInsensitive)) {
                     relevance += 0.1;
                 }
             } else if (service->genericName().contains(queryList[0], Qt::CaseInsensitive)) {
@@ -270,11 +278,11 @@ private:
                 if (service->genericName().startsWith(queryList[0], Qt::CaseInsensitive)) {
                     relevance += 0.05;
                 }
-            } else if (service->exec().contains(queryList[0], Qt::CaseInsensitive)) {
+            } else if (exec.contains(queryList[0], Qt::CaseInsensitive)) {
                 relevance = 0.7;
                 relevance += increaseMatchRelavance(service, queryList, QStringLiteral("Exec"));
 
-                if (service->exec().startsWith(queryList[0], Qt::CaseInsensitive)) {
+                if (exec.startsWith(queryList[0], Qt::CaseInsensitive)) {
                     relevance += 0.05;
                 }
             } else if (service->comment().contains(queryList[0], Qt::CaseInsensitive)) {
@@ -291,7 +299,7 @@ private:
                 relevance += .09;
             }
 
-            qCDebug(RUNNER_SERVICES) << service->name() << "is this relevant:" << relevance;
+            qCDebug(RUNNER_SERVICES) << name << "is this relevant:" << relevance;
             match.setRelevance(relevance);
 
             matches << match;
@@ -316,8 +324,13 @@ private:
             match.setType(Plasma::QueryMatch::PossibleMatch);
             setupMatch(service, match);
 
-            qreal relevance = 0.6;
-            if (service->categories().contains(QLatin1String("X-KDE-More")) || !service->showInCurrentDesktop()) {
+            qreal relevance = 0.4;
+            const QStringList categories = service->categories();
+            if (std::any_of(categories.begin(), categories.end(), [this](const QString &category) {
+                    return category.compare(term, Qt::CaseInsensitive) == 0;
+                })) {
+                relevance = 0.6;
+            } else if (service->categories().contains(QLatin1String("X-KDE-More")) || !service->showInCurrentDesktop()) {
                 relevance = 0.5;
             }
 
@@ -385,7 +398,10 @@ private:
                 match.setData(url);
 
                 qreal relevance = 0.5;
-                if (matchIndex == 0) {
+                if (action.text().compare(term, Qt::CaseInsensitive) == 0) {
+                    relevance = 0.65;
+                    match.setType(Plasma::QueryMatch::HelperMatch); // Give it a higer match type to ensure it is shown, BUG: 455436
+                } else if (matchIndex == 0) {
                     relevance += 0.05;
                 }
 
@@ -458,31 +474,3 @@ void ServiceRunner::run(const Plasma::RunnerContext &context, const Plasma::Quer
     job->setUiDelegate(delegate);
     job->start();
 }
-
-QMimeData *ServiceRunner::mimeDataForMatch(const Plasma::QueryMatch &match)
-{
-    const QUrl dataUrl = match.data().toUrl();
-
-    const QString actionName = QUrlQuery(dataUrl).queryItemValue(QStringLiteral("action"));
-    if (!actionName.isEmpty()) {
-        return nullptr;
-    }
-
-    KService::Ptr service = KService::serviceByStorageId(dataUrl.path());
-    if (!service) {
-        return nullptr;
-    }
-
-    QString path = service->entryPath();
-    if (!QDir::isAbsolutePath(path)) {
-        path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kservices5/") + path);
-    }
-
-    if (path.isEmpty()) {
-        return nullptr;
-    }
-
-    auto *data = new QMimeData();
-    data->setUrls(QList<QUrl>{QUrl::fromLocalFile(path)});
-    return data;
-}
