@@ -30,7 +30,17 @@ class DesktopView : public PlasmaQuick::ContainmentView
     Q_PROPERTY(SessionType sessionType READ sessionType CONSTANT)
 
     Q_PROPERTY(QVariantMap candidateContainments READ candidateContainmentsGraphicItems NOTIFY candidateContainmentsChanged)
-    Q_PROPERTY(QString accentColor READ accentColor WRITE setAccentColor NOTIFY accentColorChanged)
+
+    /**
+     * Whether the desktop is used in accent color extraction
+     *
+     * @note When usedInAccentColor becomes @c true, \Kirigami.ImageColors
+     * will be loaded and update the accent color, and \setAccentColor will
+     * be called
+     */
+    Q_PROPERTY(bool usedInAccentColor READ usedInAccentColor NOTIFY usedInAccentColorChanged)
+
+    Q_PROPERTY(QColor accentColor READ accentColor WRITE setAccentColor NOTIFY accentColorChanged)
 
 public:
     enum WindowType {
@@ -58,8 +68,11 @@ public:
 
     void adaptToScreen();
     void showEvent(QShowEvent *) override;
-    QString accentColor() const;
-    void setAccentColor(const QString &);
+
+    bool usedInAccentColor() const;
+
+    QColor accentColor() const;
+    void setAccentColor(const QColor &);
 
     WindowType windowType() const;
     void setWindowType(WindowType type);
@@ -81,6 +94,8 @@ protected Q_SLOTS:
     void showConfigurationInterface(Plasma::Applet *applet) override;
 
 private Q_SLOTS:
+    void slotContainmentChanged();
+    void slotScreenChanged(int newId);
     void screenGeometryChanged();
 
 Q_SIGNALS:
@@ -88,16 +103,17 @@ Q_SIGNALS:
     void windowTypeChanged();
     void candidateContainmentsChanged();
     void geometryChanged();
-    void accentColorChanged(const QString &accentColor);
+    void usedInAccentColorChanged();
+    void accentColorChanged(const QColor &accentColor);
 
 private:
     void coronaPackageChanged(const KPackage::Package &package);
     void ensureWindowType();
     void setupWaylandIntegration();
-    void setAccentColorFromWallpaper(const QString &accentColor);
+    void setAccentColorFromWallpaper(const QColor &accentColor);
     bool handleKRunnerTextInput(QKeyEvent *e);
 
-    QString m_accentColor;
+    QColor m_accentColor;
     QPointer<PlasmaQuick::ConfigView> m_configView;
     QPointer<QScreen> m_oldScreen;
     QPointer<QScreen> m_screenToFollow;
@@ -108,4 +124,8 @@ private:
     // KRunner config
     KConfigWatcher::Ptr m_configWatcher;
     bool m_activateKRunnerWhenTypingOnDesktop;
+
+    // Accent color config
+    Plasma::Containment *m_containment = nullptr;
+    int m_containmentScreenId = -1;
 };
