@@ -6,6 +6,7 @@
 
 #include <config-plasma.h>
 
+#include "../c_ptr.h"
 #include "debug.h"
 #include "panelconfigview.h"
 #include "panelshadows_p.h"
@@ -30,7 +31,6 @@
 #include <Plasma/Package>
 
 #include <KWayland/Client/plasmashell.h>
-#include <KWayland/Client/plasmawindowmanagement.h>
 #include <KWayland/Client/surface.h>
 
 #if HAVE_X11
@@ -617,13 +617,15 @@ void PanelView::resizePanel()
 
     if (formFactor() == Plasma::Types::Vertical) {
         const int minSize = qMax(MINSIZE, m_minLength);
-        const int maxSize = qMin(m_maxLength, m_screenToFollow->size().height() - m_offset);
+        int maxSize = qMin(m_maxLength, m_screenToFollow->size().height() - m_offset);
+        maxSize = qMax(minSize, maxSize);
         targetMinSize = QSize(totalThickness(), minSize);
         targetMaxSize = QSize(totalThickness(), maxSize);
-        targetSize = QSize(totalThickness(), qBound(minSize, m_contentLength, maxSize));
+        targetSize = QSize(totalThickness(), std::clamp(m_contentLength, minSize, maxSize));
     } else {
         const int minSize = qMax(MINSIZE, m_minLength);
-        const int maxSize = qMin(m_maxLength, m_screenToFollow->size().width() - m_offset);
+        int maxSize = qMin(m_maxLength, m_screenToFollow->size().width() - m_offset);
+        maxSize = qMax(minSize, maxSize);
         targetMinSize = QSize(minSize, totalThickness());
         targetMaxSize = QSize(maxSize, totalThickness());
         targetSize = QSize(std::clamp(m_contentLength, minSize, maxSize), totalThickness());
@@ -777,7 +779,7 @@ void PanelView::setAutoHideEnabled(bool enabled)
         const QByteArray effectName = QByteArrayLiteral("_KDE_NET_WM_SCREEN_EDGE_SHOW");
         xcb_intern_atom_cookie_t atomCookie = xcb_intern_atom_unchecked(c, false, effectName.length(), effectName.constData());
 
-        QScopedPointer<xcb_intern_atom_reply_t, QScopedPointerPodDeleter> atom(xcb_intern_atom_reply(c, atomCookie, nullptr));
+        UniqueCPointer<xcb_intern_atom_reply_t> atom(xcb_intern_atom_reply(c, atomCookie, nullptr));
 
         if (!atom) {
             return;
@@ -935,18 +937,10 @@ void PanelView::setScreenToFollow(QScreen *screen)
         // disconnect from old screen
         disconnect(m_screenToFollow, &QScreen::virtualGeometryChanged, this, &PanelView::updateStruts);
         disconnect(m_screenToFollow, &QScreen::geometryChanged, this, &PanelView::restore);
-        // Workaround for https://codereview.qt-project.org/c/qt/qtbase/+/413380
-        if (KWindowSystem::isPlatformX11()) {
-            disconnect(m_screenToFollow, &QScreen::logicalDotsPerInchChanged, this, &PanelView::restore);
-        }
     }
 
     connect(screen, &QScreen::virtualGeometryChanged, this, &PanelView::updateStruts, Qt::UniqueConnection);
     connect(screen, &QScreen::geometryChanged, this, &PanelView::restore, Qt::UniqueConnection);
-    // Workaround for https://codereview.qt-project.org/c/qt/qtbase/+/413380
-    if (KWindowSystem::isPlatformX11()) {
-        connect(screen, &QScreen::logicalDotsPerInchChanged, this, &PanelView::restore, Qt::UniqueConnection);
-    }
 
     /*connect(screen, &QObject::destroyed, this, [this]() {
         if (PanelView::screen()) {
@@ -1411,28 +1405,14 @@ void PanelView::refreshStatus(Plasma::Types::ItemStatus status)
     } else if (status == Plasma::Types::AcceptingInputStatus) {
         setFlags(flags() & ~Qt::WindowDoesNotAcceptFocus);
 #ifdef HAVE_X11
-        if (KWindowSystem::isPlatformX11()) {
-            m_previousWId = KWindowSystem::activeWindow();
-        }
         KWindowSystem::forceActiveWindow(winId());
 #endif
         if (m_shellSurface) {
-            m_previousPlasmaWindow = m_corona->waylandPlasmaWindowManagementInterface()->activeWindow();
             m_shellSurface->setPanelTakesFocus(true);
         }
     } else {
         if (status == Plasma::Types::PassiveStatus) {
-            // Restores the previous focus
-#ifdef HAVE_X11
-            if (KWindowSystem::isPlatformX11() && m_previousWId) {
-                KWindowSystem::forceActiveWindow(m_previousWId);
-                m_previousWId = 0;
-            }
-#endif
-            if (m_previousPlasmaWindow) {
-                m_previousPlasmaWindow->requestActivate();
-                m_previousPlasmaWindow = nullptr;
-            }
+            m_corona->restorePreviousWindow();
         }
 
         restoreAutoHide();
