@@ -38,7 +38,11 @@ protected:
 
 private:
     void setupRegistry();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override;
+#else
+    bool nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result) override;
+#endif
 
     // All
     QString m_primaryOutputName;
