@@ -102,6 +102,22 @@ ShellCorona::ShellCorona(QObject *parent)
     KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral("kdeglobals")), "KDE");
     const QString packageName = cg.readEntry("LookAndFeelPackage", QString());
     m_lookAndFeelPackage = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/LookAndFeel"), packageName);
+
+    // Accent color setting
+    KSharedConfigPtr globalConfig = KSharedConfig::openConfig();
+    KConfigGroup accentColorConfigGroup(globalConfig, "General");
+    m_accentColorFromWallpaperEnabled = accentColorConfigGroup.readEntry("accentColorFromWallpaper", false);
+
+    m_accentColorConfigWatcher = KConfigWatcher::create(globalConfig);
+    connect(m_accentColorConfigWatcher.data(), &KConfigWatcher::configChanged, this, [this](const KConfigGroup &group, const QByteArrayList &names) {
+        if (names.contains(QByteArrayLiteral("accentColorFromWallpaper"))) {
+            const bool result = group.readEntry("accentColorFromWallpaper", false);
+            if (m_accentColorFromWallpaperEnabled != result) {
+                m_accentColorFromWallpaperEnabled = result;
+                Q_EMIT accentColorFromWallpaperEnabledChanged();
+            }
+        }
+    });
 }
 
 void ShellCorona::init()
@@ -261,27 +277,7 @@ void ShellCorona::init()
     QAction *cyclePanelFocusAction = actions()->addAction(QStringLiteral("cycle-panels"));
     cyclePanelFocusAction->setText(i18n("Move keyboard focus between panels"));
     KGlobalAccel::self()->setGlobalShortcut(cyclePanelFocusAction, Qt::META | Qt::ALT | Qt::Key_P);
-    connect(cyclePanelFocusAction, &QAction::triggered, this, [this]() {
-        if (m_panelViews.isEmpty()) {
-            return;
-        }
-        PanelView *activePanel = qobject_cast<PanelView *>(qGuiApp->focusWindow());
-        if (!activePanel) {
-            activePanel = m_panelViews.values().first();
-        }
-
-        if (activePanel->containment()->status() != Plasma::Types::AcceptingInputStatus) {
-            activePanel->containment()->setStatus(Plasma::Types::AcceptingInputStatus);
-
-            auto nextItem = activePanel->rootObject()->nextItemInFocusChain();
-            if (nextItem) {
-                nextItem->forceActiveFocus();
-            }
-        } else {
-            // Cancel focus
-            activePanel->containment()->setStatus(Plasma::Types::PassiveStatus);
-        }
-    });
+    connect(cyclePanelFocusAction, &QAction::triggered, this, &ShellCorona::slotCyclePanelFocus);
 }
 
 ShellCorona::~ShellCorona()
@@ -331,13 +327,6 @@ void ShellCorona::setShell(const QString &shell)
         t->setThemeName(themeName);
     }
 
-    // FIXME: this would change the runtime platform to a fixed one if available
-    // but a different way to load platform specific components is needed beforehand
-    // because if we import and use two different components plugin, the second time
-    // the import is called it will fail
-    /* KConfigGroup cg(KSharedConfig::openConfig(package.filePath("defaults")), "General");
-     KDeclarative::KDeclarative::setRuntimePlatform(cg.readEntry("DefaultRuntimePlatform", QStringList()));*/
-
     unload();
 
     /*
@@ -745,7 +734,6 @@ void ShellCorona::load()
     connect(m_screenPool, &ScreenPool::screenAdded, this, &ShellCorona::addOutput, Qt::UniqueConnection);
     connect(m_screenPool, &ScreenPool::screenRemoved, this, &ShellCorona::handleScreenRemoved, Qt::UniqueConnection);
     connect(m_screenPool, &ScreenPool::primaryScreenChanged, this, &ShellCorona::primaryScreenChanged, Qt::UniqueConnection);
-    connect(m_desktopViewForScreen[m_screenPool->primaryScreen()], &DesktopView::accentColorChanged, this, &ShellCorona::colorChanged);
 
     if (!m_waitingPanels.isEmpty()) {
         m_waitingPanelsTimer.start();
@@ -789,10 +777,6 @@ void ShellCorona::primaryScreenChanged(QScreen *oldPrimary, QScreen *newPrimary)
 
     // can't do the screen invariant here as reconsideroutputs wasn't executed yet
     // CHECK_SCREEN_INVARIANTS
-
-    // refresh the accent color signal binding
-    disconnect(m_desktopViewForScreen.value(oldPrimary), &DesktopView::accentColorChanged, this, &ShellCorona::colorChanged);
-    connect(m_desktopViewForScreen.value(newPrimary), &DesktopView::accentColorChanged, this, &ShellCorona::colorChanged);
 }
 
 #ifndef NDEBUG
@@ -910,6 +894,79 @@ void ShellCorona::requestApplicationConfigSync()
     m_appConfigSyncTimer.start();
 }
 
+void ShellCorona::slotCyclePanelFocus()
+{
+    if (m_panelViews.empty()) {
+        return;
+    }
+
+    PanelView *activePanel = qobject_cast<PanelView *>(qGuiApp->focusWindow());
+    if (!activePanel) {
+        // Activate the first panel and save the previous window
+        activePanel = m_panelViews.begin().value();
+
+#if HAVE_X11
+        if (KWindowSystem::isPlatformX11()) {
+            m_previousWId = KWindowSystem::activeWindow();
+        }
+#endif
+        if (m_waylandWindowManagement) {
+            m_previousPlasmaWindow = m_waylandWindowManagement->activeWindow();
+        }
+    }
+
+    auto setFocus = [](PanelView *view) {
+        view->containment()->setStatus(Plasma::Types::AcceptingInputStatus);
+
+        auto nextItem = view->rootObject()->nextItemInFocusChain();
+        if (nextItem) {
+            nextItem->forceActiveFocus();
+        } else {
+            view->containment()->setStatus(Plasma::Types::PassiveStatus);
+        }
+    };
+
+    if (activePanel->containment()->status() != Plasma::Types::AcceptingInputStatus) {
+        setFocus(activePanel);
+    } else {
+        // Cancel focus on the current panel
+        // Block focus on the panel if it's not the last panel
+        if (activePanel != m_panelViews.last()) {
+            m_blockRestorePreviousWindow = true;
+        }
+        activePanel->containment()->setStatus(Plasma::Types::PassiveStatus);
+        m_blockRestorePreviousWindow = false;
+
+        // More than one panel and the current panel is not the last panel,
+        // move focus to next panel.
+        if (activePanel != m_panelViews.last()) {
+            auto viewIt = std::find_if(m_panelViews.cbegin(), m_panelViews.cend(), [activePanel](const PanelView *panel) {
+                return activePanel == panel;
+            });
+
+            if (viewIt == m_panelViews.cend()) {
+                return;
+            }
+
+            // Skip destroyed panels
+            viewIt = std::next(viewIt);
+            while (viewIt != m_panelViews.cend()) {
+                if (!viewIt.value()->containment()->destroyed()) {
+                    break;
+                }
+
+                viewIt = std::next(viewIt);
+            }
+
+            if (viewIt != m_panelViews.cend()) {
+                setFocus(viewIt.value());
+            } else {
+                restorePreviousWindow();
+            }
+        }
+    }
+}
+
 void ShellCorona::loadDefaultLayout()
 {
     // pre-startup scripts
@@ -1040,14 +1097,13 @@ QRegion ShellCorona::_availableScreenRegion(int id) const
         return s ? s->availableGeometry() : QRegion();
     }
 
-    QRegion r = view->geometry();
-    for (const PanelView *v : m_panelViews) {
+    return std::accumulate(m_panelViews.cbegin(), m_panelViews.cend(), QRegion(view->geometry()), [view](const QRegion &a, const PanelView *v) {
         if (v->isVisible() && view->screen() == v->screen() && v->visibilityMode() != PanelView::AutoHide) {
             // if the panel is being moved around, we still want to calculate it from the edge
-            r -= v->geometryByDistance(0);
+            return a - v->geometryByDistance(0);
         }
-    }
-    return r;
+        return a;
+    });
 }
 
 QRect ShellCorona::availableScreenRect(int id) const
@@ -1111,7 +1167,7 @@ void ShellCorona::removeDesktop(DesktopView *desktopView)
     }
     Q_ASSERT(deskIt != m_desktopViewForScreen.end());
 
-    QMutableHashIterator<const Plasma::Containment *, PanelView *> it(m_panelViews);
+    QMutableMapIterator<const Plasma::Containment *, PanelView *> it(m_panelViews);
     while (it.hasNext()) {
         it.next();
         PanelView *panelView = it.value();
@@ -1134,16 +1190,33 @@ PanelView *ShellCorona::panelView(Plasma::Containment *containment) const
     return m_panelViews.value(containment);
 }
 
+void ShellCorona::restorePreviousWindow()
+{
+    if (m_blockRestorePreviousWindow) {
+        return;
+    }
+
+#if HAVE_X11
+    if (KWindowSystem::isPlatformX11() && m_previousWId) {
+        KWindowSystem::forceActiveWindow(m_previousWId);
+    }
+#endif
+    if (m_previousPlasmaWindow) {
+        m_previousPlasmaWindow->requestActivate();
+    }
+
+    m_previousWId = 0;
+    m_previousPlasmaWindow = nullptr;
+}
+
 ///// SLOTS
 
 QList<PanelView *> ShellCorona::panelsForScreen(QScreen *screen) const
 {
     QList<PanelView *> ret;
-    for (PanelView *v : m_panelViews) {
-        if (v->screenToFollow() == screen) {
-            ret += v;
-        }
-    }
+    std::copy_if(m_panelViews.cbegin(), m_panelViews.cend(), std::back_inserter(ret), [screen](const PanelView *v) {
+        return v->screenToFollow() == screen;
+    });
     return ret;
 }
 
@@ -1430,13 +1503,13 @@ void ShellCorona::toggleDashboard()
     setDashboardShown(!KWindowSystem::showingDesktop());
 }
 
-QString ShellCorona::color() const
+QRgb ShellCorona::color() const
 {
     auto const primaryDesktopViewExists = m_desktopViewForScreen.contains(m_screenPool->primaryScreen());
     if (primaryDesktopViewExists) {
-        return m_desktopViewForScreen[m_screenPool->primaryScreen()]->accentColor();
+        return m_desktopViewForScreen[m_screenPool->primaryScreen()]->accentColor().rgba();
     }
-    return QStringLiteral("#00FFFFFF");
+    return QColor(Qt::transparent).rgba();
 }
 
 QString ShellCorona::evaluateScript(const QString &script)
@@ -1583,16 +1656,12 @@ Plasma::Containment *ShellCorona::setContainmentTypeForScreen(int screen, const
         return oldContainment;
     }
 
-    DesktopView *view = nullptr;
-    for (DesktopView *v : qAsConst(m_desktopViewForScreen)) {
-        if (v->containment() == oldContainment) {
-            view = v;
-            break;
-        }
-    }
+    auto viewIt = std::find_if(m_desktopViewForScreen.cbegin(), m_desktopViewForScreen.cend(), [oldContainment](const DesktopView *v) {
+        return v->containment() == oldContainment;
+    });
 
     // no view? give up
-    if (!view) {
+    if (viewIt == m_desktopViewForScreen.cend()) {
         return oldContainment;
     }
 
@@ -1650,14 +1719,14 @@ Plasma::Containment *ShellCorona::setContainmentTypeForScreen(int screen, const
     if (removeAction) {
         removeAction->deleteLater();
     }
-    view->setContainment(newContainment);
+    (*viewIt)->setContainment(newContainment);
     newContainment->setActivity(oldContainment->activity());
     insertContainment(oldContainment->activity(), screen, newContainment);
 
     // removing the focus from the item that is going to be destroyed
     // fixes a crash
     // delayout the destruction of the old containment fixes another crash
-    view->rootObject()->setFocus(true, Qt::MouseFocusReason);
+    (*viewIt)->rootObject()->setFocus(true, Qt::MouseFocusReason);
     QTimer::singleShot(2500, oldContainment, &Plasma::Applet::destroy);
 
     // Save now as we now have a screen, so lastScreen will not be -1
@@ -1689,9 +1758,9 @@ void ShellCorona::checkAddPanelAction()
     } else if (!panelContainmentPlugins.isEmpty()) {
         m_addPanelAction = new QAction(this);
         m_addPanelsMenu.reset(new QMenu);
-        m_addPanelAction->setMenu(m_addPanelsMenu.data());
-        connect(m_addPanelsMenu.data(), &QMenu::aboutToShow, this, &ShellCorona::populateAddPanelsMenu);
-        connect(m_addPanelsMenu.data(), &QMenu::triggered, this, qOverload<QAction *>(&ShellCorona::addPanel));
+        m_addPanelAction->setMenu(m_addPanelsMenu.get());
+        connect(m_addPanelsMenu.get(), &QMenu::aboutToShow, this, &ShellCorona::populateAddPanelsMenu);
+        connect(m_addPanelsMenu.get(), &QMenu::triggered, this, qOverload<QAction *>(&ShellCorona::addPanel));
     }
 
     if (m_addPanelAction) {
@@ -2030,6 +2099,11 @@ QString ShellCorona::containmentPreviewPath(Plasma::Containment *containment) co
     }
 }
 
+bool ShellCorona::accentColorFromWallpaperEnabled() const
+{
+    return m_accentColorFromWallpaperEnabled;
+}
+
 void ShellCorona::nextActivity()
 {
     m_activityController->nextActivity();
@@ -2196,11 +2270,6 @@ KWayland::Client::PlasmaShell *ShellCorona::waylandPlasmaShellInterface() const
     return m_waylandPlasmaShell;
 }
 
-KWayland::Client::PlasmaWindowManagement *ShellCorona::waylandPlasmaWindowManagementInterface() const
-{
-    return m_waylandWindowManagement;
-}
-
 ScreenPool *ShellCorona::screenPool() const
 {
     return m_screenPool;
@@ -2235,34 +2304,54 @@ void ShellCorona::configurationChanged(const QString &path)
 }
 
 void ShellCorona::activateLauncherMenu()
+{
+    auto message = QDBusMessage::createMethodCall("org.kde.KWin", "/KWin", "org.kde.KWin", "activeOutputName");
+    auto watcher = new QDBusPendingCallWatcher(QDBusConnection::sessionBus().asyncCall(message));
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this, watcher] {
+        watcher->deleteLater();
+        QDBusReply<QString> reply = *watcher;
+        if (reply.isValid()) {
+            activateLauncherMenu(reply.value());
+        }
+    });
+}
+
+void ShellCorona::activateLauncherMenu(const QString &screenName)
 {
     auto activateLauncher = [](Plasma::Applet *applet) -> bool {
         const auto provides = applet->pluginMetaData().value(QStringLiteral("X-Plasma-Provides"), QStringList());
         if (provides.contains(QLatin1String("org.kde.plasma.launchermenu"))) {
-            if (!applet->globalShortcut().isEmpty()) {
-                Q_EMIT applet->activated();
-                return true;
-            }
+            Q_EMIT applet->activated();
+            return true;
         }
         return false;
     };
 
-    for (auto it = m_panelViews.constBegin(), end = m_panelViews.constEnd(); it != end; ++it) {
-        const auto applets = it.key()->applets();
+    auto screen = m_screenPool->screenForConnector(screenName);
+
+    const auto panels = screen ? panelsForScreen(screen) : m_panelViews.values();
+    for (const auto panel : panels) {
+        const auto applets = panel->containment()->applets();
         for (auto applet : applets) {
             if (activateLauncher(applet)) {
                 return;
             }
         }
-        if (activateLauncher((*it)->containment())) {
+        if (activateLauncher(panel->containment())) {
             return;
         }
     }
-    for (auto it = m_desktopViewForScreen.constBegin(), itEnd = m_desktopViewForScreen.constEnd(); it != itEnd; ++it) {
-        if (activateLauncher((*it)->containment())) {
+
+    const auto desktops = screen ? QList{m_desktopViewForScreen.value(screen)} : m_desktopViewForScreen.values();
+    for (const auto desktop : desktops) {
+        if (activateLauncher(desktop->containment())) {
             return;
         }
     }
+
+    if (screen) {
+        activateLauncherMenu(QString());
+    }
 }
 
 void ShellCorona::activateTaskManagerEntry(int index)
