@@ -9,14 +9,15 @@
 
 #pragma once
 
+#include "config-X11.h"
 #include "plasma/corona.h"
 
 #include <QDBusContext>
 #include <QDBusVariant>
-#include <QScopedPointer>
 #include <QSet>
 #include <QTimer>
 
+#include <KConfigWatcher>
 #include <KPackage/Package>
 
 class DesktopView;
@@ -52,6 +53,8 @@ namespace KWayland
 namespace Client
 {
 class PlasmaShell;
+class PlasmaShellSurface;
+class PlasmaWindow;
 class PlasmaWindowManagement;
 }
 }
@@ -87,6 +90,7 @@ public:
     Q_INVOKABLE QStringList availableActivities() const;
 
     PanelView *panelView(Plasma::Containment *containment) const;
+    void restorePreviousWindow();
 
     // This one is a bit of an hack but are just for desktop scripting
     void insertActivity(const QString &id, const QString &plugin);
@@ -101,7 +105,6 @@ public:
     Plasma::Containment *createContainmentForActivity(const QString &activity, int screenNum);
 
     KWayland::Client::PlasmaShell *waylandPlasmaShellInterface() const;
-    KWayland::Client::PlasmaWindowManagement *waylandPlasmaWindowManagementInterface() const;
 
     ScreenPool *screenPool() const;
 
@@ -127,11 +130,17 @@ public:
     // If a containment preview has been grabbed, for this containment, return its path
     QString containmentPreviewPath(Plasma::Containment *containment) const;
 
+    /**
+     * Whether "accent color from wallpaper" option is enabled in global settings
+     */
+    bool accentColorFromWallpaperEnabled() const;
+
 Q_SIGNALS:
     void glInitializationFailed();
     // A preview for this containment has been rendered and saved to disk
     void containmentPreviewReady(Plasma::Containment *containment, const QString &path);
-    void colorChanged(const QString &color);
+    void accentColorFromWallpaperEnabledChanged();
+    void colorChanged(const QColor &color);
 
 public Q_SLOTS:
     /**
@@ -139,6 +148,11 @@ public Q_SLOTS:
      */
     void requestApplicationConfigSync();
 
+    /**
+     * Cycle through all panels
+     */
+    void slotCyclePanelFocus();
+
     /**
      * Sets the shell that the corona should display
      */
@@ -156,7 +170,7 @@ public Q_SLOTS:
     void toggleWidgetExplorer();
     QString evaluateScript(const QString &string);
     void activateLauncherMenu();
-    QString color() const;
+    QRgb color() const;
 
     QByteArray dumpCurrentLayoutJS() const;
 
@@ -239,6 +253,7 @@ private:
     void setupWaylandIntegration();
     void executeSetupPlasmoidScript(Plasma::Containment *containment, Plasma::Applet *applet);
     void checkAllDesktopsUiReady(bool ready);
+    void activateLauncherMenu(const QString &screenName);
 
 #ifndef NDEBUG
     void screenInvariants() const;
@@ -249,10 +264,14 @@ private:
     KSharedConfig::Ptr m_config;
     QString m_configPath;
 
+    // Accent color setting
+    KConfigWatcher::Ptr m_accentColorConfigWatcher;
+    bool m_accentColorFromWallpaperEnabled = false;
+
     ScreenPool *m_screenPool;
     QString m_shell;
     KActivities::Controller *m_activityController;
-    QHash<const Plasma::Containment *, PanelView *> m_panelViews;
+    QMap<const Plasma::Containment *, PanelView *> m_panelViews;
     // map from QScreen to desktop view
     QHash<const QScreen *, DesktopView *> m_desktopViewForScreen;
     QHash<const Plasma::Containment *, int> m_pendingScreenChanges;
@@ -261,9 +280,16 @@ private:
     QList<Plasma::Containment *> m_waitingPanels;
     QHash<QString, QString> m_activityContainmentPlugins;
     QAction *m_addPanelAction;
-    QScopedPointer<QMenu> m_addPanelsMenu;
+    std::unique_ptr<QMenu> m_addPanelsMenu;
     KPackage::Package m_lookAndFeelPackage;
 
+    // Used to restore the previous activated window after the panel loses focus
+    KWayland::Client::PlasmaShellSurface *m_shellSurface = nullptr;
+#if HAVE_X11
+    WId m_previousWId = 0;
+#endif
+    bool m_blockRestorePreviousWindow = false;
+
     QTimer m_waitingPanelsTimer;
     QTimer m_appConfigSyncTimer;
 #ifndef NDEBUG
@@ -272,6 +298,7 @@ private:
     KWayland::Client::PlasmaShell *m_waylandPlasmaShell;
     // For getting the active window on Wayland
     KWayland::Client::PlasmaWindowManagement *m_waylandWindowManagement = nullptr;
+    KWayland::Client::PlasmaWindow *m_previousPlasmaWindow = nullptr;
     bool m_closingDown : 1;
     QString m_testModeLayout;
 
