@@ -75,8 +75,10 @@ void gentleTermination(QProcess *p)
 
     // Wait longer for a session than a greeter
     if (!p->waitForFinished(5000)) {
-        qCWarning(PLASMA_STARTUP) << "Could not fully finish the process" << p->program();
         p->kill();
+        if (!p->waitForFinished(5000)) {
+            qCWarning(PLASMA_STARTUP) << "Could not fully finish the process" << p->program();
+        }
     }
 }
 
@@ -214,7 +216,6 @@ void setupCursor(bool wayland)
 
 std::optional<QProcessEnvironment> getSystemdEnvironment()
 {
-    QStringList list;
     auto msg = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.systemd1"),
                                               QStringLiteral("/org/freedesktop/systemd1"),
                                               QStringLiteral("org.freedesktop.DBus.Properties"),
@@ -503,6 +504,17 @@ void resetSystemdFailedUnits()
     QDBusConnection::sessionBus().call(message);
 }
 
+// Reload systemd to make sure the current configuration is active, which also reruns generators.
+// Needed for e.g. XDG autostart changes to become effective.
+void reloadSystemd()
+{
+    QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.systemd1"),
+                                                          QStringLiteral("/org/freedesktop/systemd1"),
+                                                          QStringLiteral("org.freedesktop.systemd1.Manager"),
+                                                          QStringLiteral("Reload"));
+    QDBusConnection::sessionBus().call(message);
+}
+
 bool hasSystemdService(const QString &serviceName)
 {
     qDBusRegisterMetaType<QPair<QString, QString>>();
@@ -610,6 +622,7 @@ static void migrateUserScriptsAutostart()
 bool startPlasmaSession(bool wayland)
 {
     resetSystemdFailedUnits();
+    reloadSystemd();
     OrgKdeKSplashInterface iface(QStringLiteral("org.kde.KSplash"), QStringLiteral("/KSplash"), QDBusConnection::sessionBus());
     iface.setStage(QStringLiteral("startPlasma"));
     // finally, give the session control to the session manager
@@ -654,7 +667,7 @@ bool startPlasmaSession(bool wayland)
     // Create .desktop files for the scripts in .config/autostart-scripts
     migrateUserScriptsAutostart();
 
-    QScopedPointer<QProcess, KillBeforeDeleter> startPlasmaSession;
+    std::unique_ptr<QProcess, KillBeforeDeleter> startPlasmaSession;
     if (!useSystemdBoot()) {
         startPlasmaSession.reset(new QProcess);
         qCDebug(PLASMA_STARTUP) << "Using classic boot";
@@ -669,7 +682,7 @@ bool startPlasmaSession(bool wayland)
         }
 
         startPlasmaSession->setProcessChannelMode(QProcess::ForwardedChannels);
-        QObject::connect(startPlasmaSession.data(), &QProcess::finished, &e, [&rc](int exitCode, QProcess::ExitStatus) {
+        QObject::connect(startPlasmaSession.get(), &QProcess::finished, &e, [&rc](int exitCode, QProcess::ExitStatus) {
             if (exitCode == 255) {
                 // Startup error
                 messageBox(QStringLiteral("startkde: Could not start plasma_session. Check your installation.\n"));
